<?php

namespace Drupal\posthog_cookies\Form;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The posthog_settings form.
 */
class PosthogCookiesSettingsForm extends ConfigFormBase {

  /**
   * Constructs a \Drupal\posthog_js\Form\SettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheDiscovery
   *   The cache backend.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    protected CacheBackendInterface $cacheDiscovery,
    ?TypedConfigManagerInterface $typedConfigManager = NULL,
  ) {
    parent::__construct($config_factory, $typedConfigManager);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('config.factory'),
      $container->get('cache.discovery'),
      $container->get('config.typed'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['posthog_cookies.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'posthog_cookies_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('posthog_cookies.settings');

    $form['consent_denied_persistence'] = [
      '#type' => 'select',
      '#title' => $this->t('Consent Denied Persistence'),
      '#description' => $this->t('Select the posthog persistence method for the posthog script. NOTE, that choosing anything but "Memory (default)" might be disallowed by GDPR or other data protection regulations. See <a href=":link" target="_blank">here</a> for more information on the different persistence settings.', [
        ':link' => 'https://posthog.com/docs/libraries/js#persistence',
      ]),
      '#options' => [
        'memory' => $this->t('Memory (default)'),
        'sessionStorage' => $this->t('Session Storage'),
        'localStorage' => $this->t('Local Storage'),
        'cookie' => $this->t('Cookie'),
        'localStorage+cookie' => $this->t('Local Storage + Cookie'),
      ],
      '#default_value' => $config->get('consent_denied_persistence'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('posthog_cookies.settings')
      ->set('consent_denied_persistence', $form_state->getValue('consent_denied_persistence'))
      ->save();
    $this->cacheDiscovery->invalidateAll();

    parent::submitForm($form, $form_state);
  }

}
